Learn R Programming

qtpaint (version 0.9.0)

Qanviz: Qanviz smoke library

Description

The smoke library object representing the Qanviz library underlying qtpaint. It is not usually necessary to manipulate this object directly.

Arguments